
#include "TRandom3.h"
#include "TH1F.h"
#include "TMath.h"
#include "TTree.h"
#include "TFile.h"
#include "TLorentzVector.h"
#include "TCanvas.h"

#include <cmath>

void generator_simple(Int_t events, Char_t* filename) {
  Double_t mH = 125.;        // higgs mass
  TRandom3 gen(0);  // random number generator
  Double_t sqrts = 8000.; // center of mass energy
  Double_t ymax = log(sqrts/mH);
  Double_t A = 0.01;
  Double_t B = 0.15;
  TH1F* mgg = new TH1F("mgg" ,"m_{#gamma#gamma}",60,100.,160.);
  TH1F* ygg = new TH1F("ygg" ,"y_{#gamma#gamma}",100,-10.,10.);
  TFile* myFile = TFile::Open(filename,"RECREATE");
  TTree *tree = new TTree("tree","Di-photons");
  Double_t Et1, eta1, phi1, Et2, eta2, phi2;
  tree->Branch("Et1" ,&Et1 ,"Et1/D" );
  tree->Branch("eta1",&eta1,"eta1/D");
  tree->Branch("phi1",&phi1,"phi1/D");
  tree->Branch("Et2" ,&Et2 ,"Et1/D" );
  tree->Branch("eta2",&eta2,"eta2/D");
  tree->Branch("phi2",&phi2,"phi2/D");


  for (Int_t i=0; i<events; i++) {
    Double_t phis = gen.Uniform(0.,TMath::TwoPi());
    Double_t coss = gen.Uniform(-1.,1.);
    Double_t sins = sqrt(1-coss*coss);
    TLorentzVector g1(cos(phis)*sins,sin(phis)*sins,coss,1.);
    g1*=(mH/2.);  
    TLorentzVector g2(-cos(phis)*sins,-sin(phis)*sins,-coss,1.);
    g2*=(mH/2.);
    Double_t y = gen.Uniform(-ymax,ymax);
    TLorentzVector beta(0.,0.,tanh(y),1.);
    g1.Boost(beta.BoostVector());
    g2.Boost(beta.BoostVector());
    g1*=(gen.Gaus(1.,sqrt(A*A+B*B/g1.E())));
    g2*=(gen.Gaus(1.,sqrt(A*A+B*B/g2.E())));
    if ( fabs(g1.Eta())>2.4 || fabs(g2.Eta())>2.4 ) continue;
    if ( g1.ET()<40. && g2.ET()<40. ) continue;
    if ( g1.ET()<30. || g2.ET()<30. ) continue;
    TLorentzVector H=g1+g2;
    mgg->Fill( H.M() );
    ygg->Fill( H.Rapidity() );
    Et1 =g1.Et();
    eta1=g1.Eta();
    phi1=g1.Phi();
    Et2 =g2.Et();
    eta2=g2.Eta();
    phi2=g2.Phi();
    tree->Fill();
  }

  tree->Write();
  mgg->Write();
  ygg->Write();
  myFile->Close();
  TCanvas myCanvas("myCanvas","Higgs properties",400,700);
  myCanvas.Divide(1,2);
  myCanvas.cd(1); mgg->Draw("e");
  myCanvas.cd(2); ygg->Draw("e");
}
